###################################################
### chunk number 1: aneurism load
###################################################
library(survival) 
library(intcox) 
data(aneurism.data)
aneurism.data[1:11,] 


###################################################
### chunk number 2: aneurism fit
###################################################
aneurism.fit<-intcox(Surv(left,right,type="interval2")~mo+loc,data=aneurism.data)
summary(aneurism.fit)


###################################################
### chunk number 3: aneurismplot
###################################################
surv.base<-exp(-aneurism.fit$lambda0)
plot(aneurism.fit$time.point,surv.base,type="s",xlab="time [years]",ylab="Survival function",lty=1)
lines(aneurism.fit$time.point,surv.base^exp(aneurism.fit$coefficients["mo"]),type="s",lty=2)
lines(aneurism.fit$time.point,surv.base^exp(aneurism.fit$coefficients["loc"]),type="s",lty=3)
lines(aneurism.fit$time.point,surv.base^exp(sum(aneurism.fit$coefficients[c("mo","loc")])),type="s",lty=5)
leg.names<-c("mo=0, loc=0", "mo=0, loc=1","mo=1, loc=0","mo=1, loc=1")
legend(4,1,leg.names,lty=c(1,2,3,5),bty="n")


###################################################
### chunk number 4: aneurism bootstrap
###################################################
set.seed(123)
pat<-unique(aneurism.data$gr)
intcox.boot.aneurism<-function(i,form) {
   boot.sample<-sample(pat,length(pat),replace=T)
   data.ind<-unlist(lapply(boot.sample,function(x,yy) which(yy==x),yy=aneurism.data$gr))
   data.sample<-aneurism.data[data.ind,]
   boot.fit<-intcox(form,data=data.sample, no.warnings = TRUE)
   return(list(coef=coef(boot.fit),term=boot.fit$termination))
   }
n.rep<-9                                #to be set on something like 999
aneurism.boot<-lapply(1:n.rep,intcox.boot.aneurism,form=Surv(left,right,type="interval2")~mo+loc)
aneurism.boot<-matrix(unlist(aneurism.boot),byrow=T,nrow=n.rep)
colnames(aneurism.boot)<-c(names(coef(aneurism.fit)),"termination")
inf.level<-0.05 
mo.ord<-order(aneurism.boot[,"mo"])
loc.ord<-order(aneurism.boot[,"loc"])
pos.lower<-ceiling((n.rep+1)*(inf.level/2))
pos.upper<-ceiling((n.rep+1)*(1-inf.level/2))
ci.mo<-aneurism.boot[mo.ord,"mo"][c(pos.lower,pos.upper)]
ci.loc<-aneurism.boot[mo.ord,"loc"][c(pos.lower,pos.upper)] 
ci.mo 
ci.loc
summary(aneurism.boot[,"mo"]) 
summary(aneurism.boot[,"loc"])
bias.mo<-c(mean.bias=coef(aneurism.fit)["mo"]-mean(aneurism.boot[,"mo"]),median.bias=coef(aneurism.fit)["mo"]-median(aneurism.boot[,"mo"]))
bias.loc<-c(mean.bias=coef(aneurism.fit)["loc"]-mean(aneurism.boot[,"loc"]),median.bias=coef(aneurism.fit)["loc"]-median(aneurism.boot[,"loc"]))
bias.mo 
bias.loc 
table(aneurism.boot[,"termination"])


###################################################
### chunk number 5: aneurism interaction
###################################################
aneurism.int.fit<-intcox(Surv(left,right,type="interval2")~mo*loc,data=aneurism.data)
summary(aneurism.int.fit)
set.seed(234)
n.rep<-9                                #to be set on something like 999
aneurism.int.boot<-lapply(1:n.rep,intcox.boot.aneurism,form=Surv(left,right,type="interval2")~mo*loc)
aneurism.int.boot<-matrix(unlist(aneurism.int.boot),byrow=T,nrow=n.rep)
colnames(aneurism.int.boot)<-c(names(coef(aneurism.int.fit)),"termination")
inf.level<-0.05
int.ord<-order(aneurism.int.boot[,"mo:loc"])
pos.lower<-ceiling((n.rep+1)*(inf.level/2))
pos.upper<-ceiling((n.rep+1)*(1-inf.level/2))
ci.int<-aneurism.int.boot[int.ord,"mo:loc"][c(pos.lower,pos.upper)]
ci.int
summary(aneurism.int.boot[,"mo:loc"])
bias.int<-c(mean.bias=coef(aneurism.int.fit)["mo:loc"]-mean(aneurism.int.boot[,"mo:loc"]),median.bias=coef(aneurism.int.fit)["mo:loc"]-median(aneurism.int.boot[,"mo:loc"]))
bias.int
table(aneurism.int.boot[,"termination"])


###################################################
### chunk number 6: aneurism LRT
###################################################
aneurism.int.fit$loglik
aneurism.fit$loglik


###################################################
### chunk number 7: aneurism export
###################################################
getwd()
write.table(aneurism.data, file = "aneurism.csv", sep = ",", na = "." , col.names = NA)


